@@ -120,7 +120,7 @@ class KARPClient(object):
         :param response: wait for a response
         :return:
         """
-        req = Request.create(route, request_data)
+        req = Request.create(route, request_data, response)
 
         self.writer.write(req.to_bytes())
         if response:
