@@ -37,7 +37,7 @@ class Client:
         self.requests: Dict[str, PendingRequest] = {}
 
     async def request(
-        self, route: str, data: str, response: bool, timeout: int = None
+        self, route: str, data: str, response: bool = True, timeout: int = None
     ):
         """
 
@@ -50,9 +50,13 @@ class Client:
         req: Request = Request.create(route, data, response)
         self.writer.write(req.to_bytes())
 
-        self.requests[req.request_id] = PendingRequest()
+        if response:
+            self.requests[req.request_id] = PendingRequest()
         await self.writer.drain()
 
+        if not response:
+            return
+
         try:
             response = await self.requests[req.request_id].process(
                 timeout=timeout
